﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Windows.Forms;
using RootPro.RootProCAD;
using RootPro.RootProCAD.Command;
using RootPro.RootProCAD.Geometry;
using RootPro.RootProCAD.UI;

////////////////////////////////////////////////////////////////////////////////////////////////////////////
// 選択図形の数や情報の取得、図形(線図形)の選択するアドイン
// 選択されている図形の情報、選択数を取得したり、図形を選択（サンプルでは線図形を選択）することができます。
////////////////////////////////////////////////////////////////////////////////////////////////////////////

namespace RCAddInSelectShapeCS
{
    [System.AddIn.AddIn("AppAddIn", Version = "1.0", Publisher = "", Description = "")]
    public partial class AppAddIn
    {
        private void AppAddIn_Startup(object sender, EventArgs e)
        {
            //コマンドの追加
            CommandManager.AddMacroCommand("図形の選択数", MacroCommandSelectCount);
            CommandManager.AddMacroCommand("選択図形の情報", MacroCommandSelectedInfo);
            CommandManager.AddMacroCommand("線図形の選択", MacroCommandSelectShape);
        }

        private void AppAddIn_Shutdown(object sender, EventArgs e)
        {
            //コマンドの削除
            CommandManager.RemoveMacroCommand(MacroCommandSelectCount);
            CommandManager.RemoveMacroCommand(MacroCommandSelectedInfo);
            CommandManager.RemoveMacroCommand(MacroCommandSelectShape);
        }

        #region VSTA generated code
        private void InternalStartup()
        {
            this.Startup += new System.EventHandler(AppAddIn_Startup);
            this.Shutdown += new System.EventHandler(AppAddIn_Shutdown);
        }
        #endregion

        /// <summary>
        /// 図形の選択数
        /// </summary>
        private void MacroCommandSelectCount()
        {
            SelectedShapeCollection select = ActiveDocument.SelectionManager.SelectedShapes;	//セレクトコレクションの取得

            MessageBox.Show(select.Count + " 個の図形が選択されています");
        }


        /// <summary>
        /// 選択図形の情報
        /// </summary>
        private void MacroCommandSelectedInfo()
        {
            Document doc = ActiveDocument;         //ドキュメントの取得
            SelectedShapeCollection select = doc.SelectionManager.SelectedShapes;

            Shape shape = null;
            int selectCount = select.Count;
            if (selectCount == 0)
            {
                MessageBox.Show("選択されている図形はありません");
                return;
            }


            //最初の選択の図形の情報を表示する
            shape = select[0].Shape;
            String str = "";
            str += "図形No : " + shape.Number + "\n";
            str += "図形型 : " + shape.GetType().Name + "\n";
            str += "レイヤ : " + shape.Layer.Name + "\n";
            str += "部分図 : " + shape.Drawing.Name + "\n";
            str += "属性値 : " + shape.Attributes.Count + "\n";

            MessageBox.Show(str);
        }

        /// <summary>
        /// 線図形の選択
        /// </summary>
        private void MacroCommandSelectShape()
        {
            Document doc = ActiveDocument;         //ドキュメントの取得
            Drawing drawing = doc.CurrentDrawing;  //部分図の取得
            SelectedShapeCollection select = doc.SelectionManager.SelectedShapes;

            Shape shape = null;
            int count = 0;

            while ((shape = drawing.Shapes.GetNextShape(shape)) != null)
            {
                if (!(shape is LineShape))	//線図形ではない？
                    continue;

                //図形を選択状態にします
                doc.SelectionManager.SelectShape(shape, SelectionCombineMode.Add);

                count++;
            }

            MessageBox.Show(count + " の図形を選択しました");
        }
    }
}
